==> deepin-ocr_6.5.0.tar.xz: BUILD/translations/deepin-ocr_ne.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ne">
<context>
    <name>MainWidget</name>
    <message>
        <location filename="../src/mainwidget.cpp" line="115"/>
        <source>No text recognized</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="166"/>
        <source>Recognize language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="169"/>
        <source>Simplified Chinese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="169"/>
        <source>English</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="169"/>
        <source>Traditional Chinese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="204"/>
        <source>Copy text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="210"/>
        <source>Save as TXT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="236"/>
        <source>Undo (Ctrl+Z)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="247"/>
        <source>Redo (Ctrl+Shift+Z)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="294"/>
        <location filename="../src/mainwidget.cpp" line="335"/>
        <source>Recognizing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="563"/>
        <source>Copied</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="75"/>
        <source>OCR Tool</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ResultTextView</name>
    <message>
        <location filename="../src/resulttextview.cpp" line="22"/>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="24"/>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="27"/>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="29"/>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Widget</name>
    <message>
        <location filename="../src/mainwidget.cpp" line="283"/>
        <source>Tips: The clearer the image is, the more accurate the text is</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> deepin-ocr_6.5.9.tar.xz: BUILD/translations/deepin-ocr_ne.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ne">
<context>
    <name>MainWidget</name>
    <message>
        <location filename="../src/mainwidget.cpp" line="115"/>
        <source>No text recognized</source>
        <translation>कुनै पनि पाठ चिनियो</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="166"/>
        <source>Recognize language</source>
        <translation>भाषा चिनियो</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="169"/>
        <source>Simplified Chinese</source>
        <translation>सरलीकृत चीनी</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="169"/>
        <source>English</source>
        <translation>अंग्रेजी</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="169"/>
        <source>Traditional Chinese</source>
        <translation>पारंपरिक चीनी</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="204"/>
        <source>Copy text</source>
        <translation>पाठ काट्नु</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="210"/>
        <source>Save as TXT</source>
        <translation>TXT मा सेभ गर्नु</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="236"/>
        <source>Undo (Ctrl+Z)</source>
        <translation>पुन: गर्नु (Ctrl+Z)</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="247"/>
        <source>Redo (Ctrl+Shift+Z)</source>
        <translation>पुन: गर्नु (Ctrl+Shift+Z)</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="294"/>
        <source>Recognizing</source>
        <translation>चिनिरहेको</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="563"/>
        <source>Copied</source>
        <translation>काटियो</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="75"/>
        <source>OCR Tool</source>
        <translation>OCR टोल</translation>
    </message>
</context>
<context>
    <name>ResultTextView</name>
    <message>
        <location filename="../src/resulttextview.cpp" line="22"/>
        <source>Copy</source>
        <translation>काट्नु</translation>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="24"/>
        <source>Cut</source>
        <translation>काट्नु</translation>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="27"/>
        <source>Select All</source>
        <translation>सबै चयन गर्नु</translation>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="29"/>
        <source>Paste</source>
        <translation>पेस्ट गर्नु</translation>
    </message>
</context>
<context>
    <name>Widget</name>
    <message>
        <location filename="../src/mainwidget.cpp" line="283"/>
        <source>Tips: The clearer the image is, the more accurate the text is</source>
        <translation>सुझाव: छवि ज्यादा स्पष्ट हुन त्यो पाठ ज्यादा सटीक हुन्छ</translation>
    </message>
</context>
</TS>
